summaryrefslogtreecommitdiffstats
path: root/part/kxe_treeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/kxe_treeview.h')
-rw-r--r--part/kxe_treeview.h90
1 files changed, 45 insertions, 45 deletions
diff --git a/part/kxe_treeview.h b/part/kxe_treeview.h
index 0ba2c86..1b642f5 100644
--- a/part/kxe_treeview.h
+++ b/part/kxe_treeview.h
@@ -19,19 +19,19 @@
#define KXE_TREEVIEW_H
#include <klistview.h>
-#include <qstrlist.h>
+#include <tqstrlist.h>
class KXESearchDialog;
-class QDomDocument;
-class QDomNode;
-class QDomElement;
-class QDomCharacterData;
-class QDomProcessingInstruction;
+class TQDomDocument;
+class TQDomNode;
+class TQDomElement;
+class TQDomCharacterData;
+class TQDomProcessingInstruction;
-class QMouseEvent;
-class QTimer;
-class QKeyEvent;
+class TQMouseEvent;
+class TQTimer;
+class TQKeyEvent;
class KXMLGUIClient;
class KXE_TreeViewItem;
@@ -44,7 +44,7 @@ class KXE_TreeView : public KListView
Q_OBJECT
public:
- KXE_TreeView( KXMLGUIClient * pGUIClient, QWidget * pParent = 0, const char * pszName = 0 );
+ KXE_TreeView( KXMLGUIClient * pGUIClient, TQWidget * pParent = 0, const char * pszName = 0 );
/** Changes the behaviour of this view to readonly or readwrite. */
void setReadWrite( bool fReadWrite );
@@ -54,22 +54,22 @@ public:
/** Selects the item corresponding to the given node.
* Returns true on success, false otherwise. */
- bool selectNode( const QDomNode & node );
+ bool selectNode( const TQDomNode & node );
/** Returns the a pointer to the selected items node or a null pointer (if no item is selected). */
- QDomNode * getSelectedNode() const;
+ TQDomNode * getSelectedNode() const;
/** Returns the a pointer to the special processing instruction or a null pointer for (if no item is exists). */
- QDomNode * getSpecProcInstrNode(const QString& target) const;
+ TQDomNode * getSpecProcInstrNode(const TQString& target) const;
/** Returns the selected items path or an empty string, if no item is selected. */
- QString getSelectedPath() const;
+ TQString getSelectedPath() const;
/** Returns true, if this tree view contains bookmarked tree items and false otherwise. */
bool containsBookmarkedItems() const { return (m_nBookmarkedItems>0); }
/** Drop or paste text into item */
- bool drop(QListViewItem *, QDropEvent *);
+ bool drop(TQListViewItem *, TQDropEvent *);
/** toggles bookmark on the selected item */
void bookmarksToggle();
@@ -96,16 +96,16 @@ public:
* Creates new item(s) to the given node (and its child nodes)
* and inserts it (or them) in the tree.
*/
- void updateNodeCreated( const QDomNode & node );
+ void updateNodeCreated( const TQDomNode & node );
/** Changes the item corresponding to the given node. */
- void updateNodeChanged( const QDomNode & node );
+ void updateNodeChanged( const TQDomNode & node );
/** Removes the item corresponding to the given node. */
- void updateNodeDeleted( const QDomNode & node );
+ void updateNodeDeleted( const TQDomNode & node );
/** Moves the item corresponding to the given node. */
- void updateNodeMoved( const QDomNode & node );
+ void updateNodeMoved( const TQDomNode & node );
/** Clears the whole tree. */
void updateClear();
@@ -117,7 +117,7 @@ public:
* class functionality is used and the signal
* @ref sigItemRenamedInplace emitted.
*/
- virtual void rename( QListViewItem * pItem, int nColumn );
+ virtual void rename( TQListViewItem * pItem, int nColumn );
/** Returns info, is root element is already created */
bool hasRootNode();
@@ -140,13 +140,13 @@ signals:
void sigSelectionCleared(bool);
/** emitted, when an XML element item is selected */
- void sigSelectionChanged( const QDomElement & );
+ void sigSelectionChanged( const TQDomElement & );
/** emitted, when an XML Content item is selected */
- void sigSelectionChanged( const QDomCharacterData & );
+ void sigSelectionChanged( const TQDomCharacterData & );
/** emitted, when an XML proc.instr. item is selected */
- void sigSelectionChanged( const QDomProcessingInstruction & );
+ void sigSelectionChanged( const TQDomProcessingInstruction & );
/**
* Signals the change of bookmark status.
@@ -156,35 +156,35 @@ signals:
void sigNewBookmarkStatus( bool fStatus );
/** Emitted, when a context menu is requested */
- void sigContextMenuRequested( const QString & szMenuName, const QPoint & pos );
+ void sigContextMenuRequested( const TQString & szMenuName, const TQPoint & pos );
/** Emitted when user presses a key. */
- void sigKeyPressed(QKeyEvent* e);
+ void sigKeyPressed(TQKeyEvent* e);
protected:
/** if RMB shows the popupmenu corresponding to the selected item */
- void contentsMousePressEvent( QMouseEvent * );
+ void contentsMousePressEvent( TQMouseEvent * );
/** Finds the corresponding treeview item to the given node. */
- KXE_TreeViewItem * findCorrespondingItem( const QDomNode & node );
+ KXE_TreeViewItem * findCorrespondingItem( const TQDomNode & node );
/** Overrides KListView::contentsMouseReleaseEvent */
- void contentsMouseReleaseEvent(QMouseEvent *);
+ void contentsMouseReleaseEvent(TQMouseEvent *);
/** Overrides KListView::contentsMouseMoveEvent */
- void contentsMouseMoveEvent(QMouseEvent *);
+ void contentsMouseMoveEvent(TQMouseEvent *);
- /** Overrides QScrollView::contentsDragEnterEvent */
- void contentsDragEnterEvent(QDragEnterEvent *);
+ /** Overrides TQScrollView::contentsDragEnterEvent */
+ void contentsDragEnterEvent(TQDragEnterEvent *);
- /** Overrides QScrollView::contentsDragMoveEvent */
- void contentsDragMoveEvent(QDragMoveEvent *);
+ /** Overrides TQScrollView::contentsDragMoveEvent */
+ void contentsDragMoveEvent(TQDragMoveEvent *);
- /** Overrides QScrollView::contentsDragLeaveEvent */
- void contentsDragLeaveEvent(QDragLeaveEvent *);
+ /** Overrides TQScrollView::contentsDragLeaveEvent */
+ void contentsDragLeaveEvent(TQDragLeaveEvent *);
- /** Overrides QScrollView::contentsDropEvent */
- void contentsDropEvent(QDropEvent *);
- virtual void keyPressEvent(QKeyEvent *e);
+ /** Overrides TQScrollView::contentsDropEvent */
+ void contentsDropEvent(TQDropEvent *);
+ virtual void keyPressEvent(TQKeyEvent *e);
protected slots:
/** Checks, which type of item was selected an emits the corresponding signal. */
@@ -196,9 +196,9 @@ protected slots:
* because KXMLEditor could have been in "create items on demand" mode during
* the opening of the document.
*
* To be connected to the signal QListView::expanded(QListViewItem*).
*/
- void slotItemExpanded( QListViewItem * );
+ void slotItemExpanded( TQListViewItem * );
private slots:
@@ -217,19 +217,19 @@ protected:
bool m_bDrag;
/** Contain mouse position of drag operation */
- QPoint m_dragPos;
+ TQPoint m_dragPos;
/** The item that was current before the drag-enter event happened */
- QListViewItem *m_pCurrentBeforeDropItem;
+ TQListViewItem *m_pCurrentBeforeDropItem;
/** The item we are moving the mouse over (during a drag) */
- QListViewItem *m_pDropItem;
+ TQListViewItem *m_pDropItem;
/** List of avalilable drop formats */
- QStrList m_lstDropFormats;
+ TQStrList m_lstDropFormats;
/** Timer for counting time to auto open fselected folder while drag */
- QTimer *m_autoOpenTimer;
+ TQTimer *m_autoOpenTimer;
};
#endif
@@ -196,9 +196,9 @@ protected slots:
* the opening of the document.
*
- * To be connected to the signal QListView::expanded(QListViewItem*).
+ * To be connected to the signal TQListView::expanded(TQListViewItem*).
*/